@@ -5,7 +5,7 @@ use warnings;
 
 use IO::File;
 
-our $VERSION = "0.76";
+our $VERSION = "0.77";
 our $modeline;
 
 require Exporter;
@@ -92,6 +92,12 @@ __DATA__
 {{body}}    
 <!-- end content-->
 </div>
+<div id="sidebar">
+<!-- begin navigation per folder -->
+<!-- end navigation -->
+<!-- begin sidebar -->
+<!-- end sidebar -->
+</div>
 </body>
 </html>
 
@@ -116,6 +122,12 @@ __DATA__
 <!-- endloop -->
 <!-- end content-->
 </div>
+<div id="sidebar">
+<!-- begin navigation per folder -->
+<!-- end navigation -->
+<!-- begin sidebar -->
+<!-- end sidebar -->
+</div>
 </body>
 </html>
 
@@ -141,6 +153,12 @@ __DATA__
 </ul>
 <!-- end content-->
 </div>
+<div id="sidebar">
+<!-- begin navigation per folder -->
+<!-- end navigation -->
+<!-- begin sidebar -->
+<!-- end sidebar -->
+</div>
 </body>
 </html>
 
